@@ -3,7 +3,7 @@
 import sys
 from argparse import Namespace
 from pprint import pprint
-from typing import Any, NoReturn
+from typing import NoReturn
 
 from .argparse import ArgumentParserWithUnknowns
 from .config import PikaurConfig
@@ -11,6 +11,7 @@ from .i18n import translate, translate_many
 
 
 ArgSchema = list[tuple[str | None, str, None | bool | str | int]]
+PossibleArgValuesTypes = list[str] | str | bool | int | None
 
 
 PACMAN_BOOL_OPTS: ArgSchema = [
@@ -18,7 +19,7 @@ PACMAN_BOOL_OPTS: ArgSchema = [
     ('S', 'sync', None),
     ('g', 'groups', None),
     ('w', 'downloadonly', None),
-    ('q', 'quiet', None),
+    ('q', 'quiet', False),
     ('s', 'search', None),
     ('d', 'nodeps', None),
     # query options
@@ -37,7 +38,7 @@ PACMAN_BOOL_OPTS: ArgSchema = [
     ('v', 'verbose', None),
     (None, 'debug', None),
     (None, 'noconfirm', None),
-    (None, 'needed', None),
+    (None, 'needed', False),
 ]
 
 
@@ -45,7 +46,7 @@ def get_pikaur_bool_opts() -> ArgSchema:
     return [
         (None, 'noedit', PikaurConfig().review.NoEdit.get_bool()),
         (None, 'edit', None),
-        (None, 'namesonly', None),
+        (None, 'namesonly', False),
         (None, 'repo', None),
         ('a', 'aur', None),
         (None, 'keepbuild', PikaurConfig().build.KeepBuildDir.get_bool()),
@@ -145,12 +146,29 @@ class PikaurArgs(Namespace):
     owns: bool | None
     check: bool | None
     ignore: list[str]
+    makepkg_config: str | None
+    mflags: str | None
+    makepkg_path: str | None
+    quiet: bool
+    sysupgrade: int
+    devel: int
+    namesonly: bool
+    build_gpgdir: str
+    needed: bool
+    config: str | None
+    refresh: int
+    clean: int
     # positional: List[str]
     # @TODO: pylint bug:
     positional: list[str] = []
 
-    def __getattr__(self, name: str) -> Any:
-        return getattr(super(), name, getattr(self, name.replace('-', '_')))
+    def __getattr__(self, name: str) -> PossibleArgValuesTypes:
+        result: PossibleArgValuesTypes = getattr(
+            super(),
+            name,
+            getattr(self, name.replace('-', '_'))
+        )
+        return result
 
     def handle_the_same_letter(self) -> None:
         # pylint: disable=attribute-defined-outside-init
@@ -240,7 +258,7 @@ class PikaurArgumentParser(ArgumentParserWithUnknowns):
             action: str | None = None,
             letter: str | None = None,
             opt: str | None = None,
-            default: Any | None = None
+            default: PossibleArgValuesTypes = None
     ) -> None:
         if action:
             if letter and opt:
