@@ -11,11 +11,12 @@ from .pacman_i18n import _p
 from .pprint import ColorsHighlight, bold_line, color_line
 
 
-def _info_packages_thread_repo() -> str:
+def _info_packages_thread_repo() -> str | None:
     args = parse_args()
-    return spawn(
+    proc = spawn(
         get_pacman_command() + reconstruct_args(args, ignore_args=['refresh']) + args.positional
-    ).stdout_text
+    )
+    return proc.stdout_text
 
 
 INFO_FIELDS = {
